==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DiagnozaGrOsPlanWsparciaKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class DiagnozaGrOsPlanWsparciaKey extends GenericDPSObject {
    /**
     * DIAGNOZA_GR_OS_PLAN_WSPARCIA.GRUPA_OSOB_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long grupaOsobId;

    /**
     * DIAGNOZA_GR_OS_PLAN_WSPARCIA.CZYNNOSC_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long czynnoscId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DIAGNOZA_GR_OS_PLAN_WSPARCIA.GRUPA_OSOB_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getGrupaOsobId() {
        return grupaOsobId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * DIAGNOZA_GR_OS_PLAN_WSPARCIA.GRUPA_OSOB_ID
     *
     * @param grupaOsobId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setGrupaOsobId(Long grupaOsobId) {
        this.grupaOsobId = grupaOsobId;
    }

    /**
     * @return DIAGNOZA_GR_OS_PLAN_WSPARCIA.CZYNNOSC_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getCzynnoscId() {
        return czynnoscId;
    }

    /**
     * DIAGNOZA_GR_OS_PLAN_WSPARCIA.CZYNNOSC_ID
     *
     * @param czynnoscId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setCzynnoscId(Long czynnoscId) {
        this.czynnoscId = czynnoscId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DiagnozaGrOsPlanWsparciaKey other = (DiagnozaGrOsPlanWsparciaKey) that;
        return (this.getGrupaOsobId() == null ? other.getGrupaOsobId() == null : this.getGrupaOsobId().equals(other.getGrupaOsobId()))
            && (this.getCzynnoscId() == null ? other.getCzynnoscId() == null : this.getCzynnoscId().equals(other.getCzynnoscId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getGrupaOsobId() == null) ? 0 : getGrupaOsobId().hashCode());
        result = prime * result + ((getCzynnoscId() == null) ? 0 : getCzynnoscId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", grupaOsobId=").append(grupaOsobId);
        sb.append(", czynnoscId=").append(czynnoscId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DiagnozaGrOsPlanWsparciaKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class DiagnozaGrOsPlanWsparciaKey extends GenericDPSObject {
    /**
     * DIAGNOZA_GR_OS_PLAN_WSPARCIA.GRUPA_OSOB_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long grupaOsobId;

    /**
     * DIAGNOZA_GR_OS_PLAN_WSPARCIA.CZYNNOSC_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long czynnoscId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DIAGNOZA_GR_OS_PLAN_WSPARCIA.GRUPA_OSOB_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getGrupaOsobId() {
        return grupaOsobId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:47
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * DIAGNOZA_GR_OS_PLAN_WSPARCIA.GRUPA_OSOB_ID
     *
     * @param grupaOsobId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setGrupaOsobId(Long grupaOsobId) {
        this.grupaOsobId = grupaOsobId;
    }

    /**
     * @return DIAGNOZA_GR_OS_PLAN_WSPARCIA.CZYNNOSC_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getCzynnoscId() {
        return czynnoscId;
    }

    /**
     * DIAGNOZA_GR_OS_PLAN_WSPARCIA.CZYNNOSC_ID
     *
     * @param czynnoscId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setCzynnoscId(Long czynnoscId) {
        this.czynnoscId = czynnoscId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DiagnozaGrOsPlanWsparciaKey other = (DiagnozaGrOsPlanWsparciaKey) that;
        return (this.getGrupaOsobId() == null ? other.getGrupaOsobId() == null : this.getGrupaOsobId().equals(other.getGrupaOsobId()))
            && (this.getCzynnoscId() == null ? other.getCzynnoscId() == null : this.getCzynnoscId().equals(other.getCzynnoscId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getGrupaOsobId() == null) ? 0 : getGrupaOsobId().hashCode());
        result = prime * result + ((getCzynnoscId() == null) ? 0 : getCzynnoscId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", grupaOsobId=").append(grupaOsobId);
        sb.append(", czynnoscId=").append(czynnoscId);
        sb.append("]");
        return sb.toString();
    }
}
